@@ -417,6 +417,11 @@ gtk_file_system_gio_init (GtkFileSystemGio *impl)
 
   DEBUG ("init");
 
+  bindtextdomain (GETTEXT_PACKAGE, GNOMEUILOCALEDIR);
+#ifdef HAVE_BIND_TEXTDOMAIN_CODESET 
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#endif
+
   impl->volume_monitor = g_volume_monitor_get ();
 
   path = get_bookmarks_filename ();
@@ -875,13 +880,24 @@ translate_file_info (GFile     *file,
   GtkFileInfo *info;
   gboolean is_folder;
   GTimeVal mtime;
-  const gchar *thumbnail_path;
+  const gchar *thumbnail_path, *display_name;
 
   info = gtk_file_info_new ();
   is_folder = (g_file_info_get_file_type (file_info) == G_FILE_TYPE_DIRECTORY);
   g_file_info_get_modification_time (file_info, &mtime);
 
-  gtk_file_info_set_display_name (info, g_file_info_get_display_name (file_info));
+  display_name = g_file_info_get_display_name (file_info);
+  if (display_name == NULL) {
+    const gchar *name;
+    gchar *d_name;
+
+    name = g_file_info_get_name (file_info);
+    d_name = g_filename_display_name (name);
+    gtk_file_info_set_display_name (info, d_name);
+    g_free (d_name);
+  } else {
+    gtk_file_info_set_display_name (info, display_name);
+  }
   gtk_file_info_set_is_folder (info, is_folder);
   gtk_file_info_set_is_hidden (info, g_file_info_get_is_hidden (file_info));
   gtk_file_info_set_mime_type (info, g_file_info_get_content_type (file_info));
@@ -1339,6 +1355,7 @@ gtk_file_system_gio_volume_get_icon_name (GtkFileSystem        *file_system,
     }
 
   name = get_icon_string (icon);
+  g_object_unref (icon);
 
   return name;
 }
@@ -1542,7 +1559,6 @@ read_bookmarks_file (void)
 {
   gchar *filename, *contents;
   gchar **lines, *space;
-  GError *error = NULL;
   GList *bookmarks = NULL;
   GFile *file;
   gint i;
@@ -1580,7 +1596,7 @@ read_bookmarks_file (void)
   g_free (contents);
   g_object_unref (file);
 
-  return bookmarks;
+  return g_list_reverse (bookmarks);
 }
 
 static void
@@ -1592,12 +1608,6 @@ save_bookmarks_file (GList *bookmarks)
   GList *elem;
   GFile *file;
 
-  /* read_bookmarks_file returns the list reversed
-   * in order to just prepend elements in list_bookmarks,
-   * so to keep the same order we have to reverse it here
-   */
-  bookmarks = g_list_reverse (bookmarks);
-
   filename = get_bookmarks_filename ();
   file = g_file_new_for_path (filename);
   g_free (filename);
@@ -1749,6 +1759,7 @@ gtk_file_system_gio_list_bookmarks (GtkFileSystem *file_system)
 
   DEBUG ("list_bookmarks");
   bookmarks = read_bookmarks_file ();
+  bookmarks = g_list_reverse (bookmarks);
 
   for (elem = bookmarks; elem; elem = elem->next)
     {
@@ -1885,6 +1896,9 @@ gtk_file_folder_gio_get_info (GtkFileFolder      *folder,
 
   DEBUG ("folder_get_info");
 
+  if (path == NULL)
+    return NULL;
+
   folder_gio = GTK_FILE_FOLDER_GIO (folder);
   uri = gtk_file_path_get_string (path);
   file_info = g_hash_table_lookup (folder_gio->children,
